MemberActionModel class

Constructors

MemberActionModel({required String documentID, String? text, String? description, ActionModel? action})

Properties

action ↔ ActionModel?
getter/setter pair
description ↔ String?
getter/setter pair
documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? text, String? description, ActionModel? action}) → MemberActionModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → MemberActionEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, MemberActionEntity? entity) → Future<MemberActionModel?>
fromEntityPlus(String documentID, MemberActionEntity? entity, {String? appId}) → Future<MemberActionModel?>

Constants

id → const String
packageName → const String